@@ -29,10 +29,11 @@ with 'Firewall::Config::Parser::Role';
 sub parse {
   my $self = shift;
   $self->{ruleNum} = 0;
-  while ( defined( my $string = $self->nextUnParsedLine ) ) {
-    if    ( $self->isRoute($string) ) { $self->parseRoute($string) }
-    elsif ( $self->isInterfaceZone($string) ) {$self->parseInterfaceZone($string)}
-    elsif ( $self->isNatPool($string) ) {$self->parseNatPool($string)}
+  while (defined(my $string = $self->nextUnParsedLine)) {
+    if    ($self->isRoute($string))         { $self->parseRoute($string) }
+    elsif ($self->isInterfaceZone($string)) { $self->parseInterfaceZone($string) }
+    elsif ($self->isNatPool($string))       { $self->parseNatPool($string) }
+
     #when ( $self->isActive($string)       ) { $self->setActive($string)         }
     else { $self->ignoreLine }
   }
@@ -40,23 +41,23 @@ sub parse {
   $self->addZoneRange;
 
   $self->goToHeadLine;
-  while ( defined( my $string = $self->nextUnParsedLine ) ) {
-    if    ( $self->isStaticNat($string) ) { $self->parseStaticNat($string) }
-    elsif ( $self->isDynamicNat($string) ) {$self->parseDynamicNat($string)}
-    elsif ( $self->isAddress($string) ) {$self->parseAddress($string)}
-    elsif ( $self->isAddressGroup($string) ) {$self->parseAddressGroup($string)}
-    elsif ( $self->isService($string) ) {$self->parseService($string)}
-    elsif ( $self->isServiceGroup($string) ) {$self->parseServiceGroup($string)}
-    elsif ( $self->isSchedule($string) ) {$self->parseSchedule($string)}
-    elsif ( $self->isRule($string) ) {$self->parseRule($string)}
-    else {$self->ignoreLine}
+  while (defined(my $string = $self->nextUnParsedLine)) {
+    if    ($self->isStaticNat($string))    { $self->parseStaticNat($string) }
+    elsif ($self->isDynamicNat($string))   { $self->parseDynamicNat($string) }
+    elsif ($self->isAddress($string))      { $self->parseAddress($string) }
+    elsif ($self->isAddressGroup($string)) { $self->parseAddressGroup($string) }
+    elsif ($self->isService($string))      { $self->parseService($string) }
+    elsif ($self->isServiceGroup($string)) { $self->parseServiceGroup($string) }
+    elsif ($self->isSchedule($string))     { $self->parseSchedule($string) }
+    elsif ($self->isRule($string))         { $self->parseRule($string) }
+    else                                   { $self->ignoreLine }
   } ## end while ( defined( my $string...))
   $self->{config} = "";
 } ## end sub parse
 
 sub isActive {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /.+\(M|B\)->\s*/i ) {
+  my ($self, $string) = @_;
+  if ($string =~ /.+\(M|B\)->\s*/i) {
     return 1;
   }
   else {
@@ -66,8 +67,8 @@ sub isActive {
 }
 
 sub setActive {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /.+\((.+)\)->\s*/i ) {
+  my ($self, $string) = @_;
+  if ($string =~ /.+\((.+)\)->\s*/i) {
     my $active = 1;
     my $backup = 0;
     $active = 0 if uc $1 eq 'B';
@@ -97,8 +98,8 @@ sub setActive {
 #set interface ethernet1/3.2 vip 210.21.223.59 + 15000 "5000" 192.168.170.227
 
 sub isDynamicNat {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /set\s+interface\s+\S+\s+vip/oxi ) {
+  my ($self, $string) = @_;
+  if ($string =~ /set\s+interface\s+\S+\s+vip/oxi) {
     $self->setElementType('dynamicNat');
     return 1;
   }
@@ -109,24 +110,23 @@ sub isDynamicNat {
 }
 
 sub parseDynamicNat {
-  my ( $self, $string ) = @_;
-  if ( $string
-    =~ /set\s+interface\s+(?<interface>\S+)\s+vip\s+(?<natIp>\S+)\s+(\+\s+)?(?<natPort>\S+)\s+"(?<srv>\S+)"\s+(?<realIp>\S+)/oxi
-    )
+  my ($self, $string) = @_;
+  if ($string
+    =~ /set\s+interface\s+(?<interface>\S+)\s+vip\s+(?<natIp>\S+)\s+(\+\s+)?(?<natPort>\S+)\s+"(?<srv>\S+)"\s+(?<realIp>\S+)/oxi)
   {
     my %param;
     $param{config}     = $string;
-    $param{fromZone}   = $self->getInterface( $+{interface} )->{zoneName};
-    $param{toZone}     = $self->getZoneFromIp( $+{realIp}, 32 );
-    $param{srcIpRange} = Firewall::Utils::Ip->new->getRangeFromIpMask( '0.0.0.0',  '0' );
-    $param{dstIpRange} = Firewall::Utils::Ip->new->getRangeFromIpMask( $+{realIp}, '32' );
-    my $serv = $self->getServiceOrServiceGroupFromSrvGroupMemberName( $+{srv} );
+    $param{fromZone}   = $self->getInterface($+{interface})->{zoneName};
+    $param{toZone}     = $self->getZoneFromIp($+{realIp}, 32);
+    $param{srcIpRange} = Firewall::Utils::Ip->new->getRangeFromIpMask('0.0.0.0',  '0');
+    $param{dstIpRange} = Firewall::Utils::Ip->new->getRangeFromIpMask($+{realIp}, '32');
+    my $serv = $self->getServiceOrServiceGroupFromSrvGroupMemberName($+{srv});
     $param{srv}      = $serv;
     $param{srvRange} = $serv->range if defined $serv;
     my $protoNum = $serv->range->mins->[0] >> 16;
     $param{natSrvRange}   = Firewall::Utils::Ip->new->getRangeFromService("$protoNum/$+{natPort}");
     $param{natDstIp}      = $+{natIp};
-    $param{natDstIpRange} = Firewall::Utils::Ip->new->getRangeFromIpMask( $+{natIp}, '32' );
+    $param{natDstIpRange} = Firewall::Utils::Ip->new->getRangeFromIpMask($+{natIp}, '32');
     $param{natDirection}  = 'destination';
     $param{natDstPort}    = $+{natPort};
     $param{fwId}          = $self->fwId;
@@ -149,8 +149,8 @@ sub parseDynamicNat {
 } ## end sub parseDynamicNat
 
 sub isNatPool {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /^set\s+interface\s+\S+\s+(?:ext|dip)\s+/ox ) {
+  my ($self, $string) = @_;
+  if ($string =~ /^set\s+interface\s+\S+\s+(?:ext|dip)\s+/ox) {
     $self->setElementType('natPool');
     return 1;
   }
@@ -161,12 +161,12 @@ sub isNatPool {
 }
 
 sub getNatPool {
-  my ( $self, $name ) = @_;
-  return $self->getElement( 'natPool', $name );
+  my ($self, $name) = @_;
+  return $self->getElement('natPool', $name);
 }
 
 sub parseNatPool {
-  my ( $self, $string ) = @_;
+  my ($self, $string) = @_;
   if (
     $string =~ /^set\s+interface\s+(?<interface>\S+)
         (?:\s+ext\s+ip\s+(?<extIp>\d+\.\d+\.\d+\.\d+)\s+(?<extMask>\d+\.\d+\.\d+\.\d+))?
@@ -192,8 +192,8 @@ sub parseNatPool {
 #set interface "ethernet0/1.1" tag 179 zone "DMZ-2"
 
 sub isInterfaceZone {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /^set \s+ interface \s+ \S+ \s+ (tag\s+\S+\s+)* ((zone \s+\S+)|(ip \s+\d+\S+)) \s*/ox ) {
+  my ($self, $string) = @_;
+  if ($string =~ /^set \s+ interface \s+ \S+ \s+ (tag\s+\S+\s+)* ((zone \s+\S+)|(ip \s+\d+\S+)) \s*/ox) {
     $self->setElementType('interfaceZone');
     return 1;
   }
@@ -208,13 +208,13 @@ sub addRouteToInterface {
   my $self           = shift;
   my $interfaceIndex = $self->elements->{interface};
   my $routeIndex     = $self->elements->{route};
-  foreach my $interface ( values %{$interfaceIndex} ) {
-    if ( defined $interface->{ipAddress} ) {
-      foreach my $route ( values %{$routeIndex} ) {
-        if ( defined $route->{nextHop} and $route->{type} eq 'static' ) {
-          my $intIpSet   = Firewall::Utils::Ip->new->getRangeFromIpMask( $interface->{ipAddress}, $interface->{mask} );
-          my $nextHopSet = Firewall::Utils::Ip->new->getRangeFromIpMask( $route->{nextHop},       32 );
-          if ( $intIpSet->isContain($nextHopSet) ) {
+  foreach my $interface (values %{$interfaceIndex}) {
+    if (defined $interface->{ipAddress}) {
+      foreach my $route (values %{$routeIndex}) {
+        if (defined $route->{nextHop} and $route->{type} eq 'static') {
+          my $intIpSet   = Firewall::Utils::Ip->new->getRangeFromIpMask($interface->{ipAddress}, $interface->{mask});
+          my $nextHopSet = Firewall::Utils::Ip->new->getRangeFromIpMask($route->{nextHop},       32);
+          if ($intIpSet->isContain($nextHopSet)) {
             $interface->addRoute($route);
             $route->{zoneName} = $interface->{zoneName};
           }
@@ -226,35 +226,32 @@ sub addRouteToInterface {
 
 sub addZoneRange {
   my $self = shift;
-  foreach my $zone ( values %{$self->elements->{zone}} ) {
-    foreach my $interface ( values %{$zone->interfaces} ) {
-      $zone->range->mergeToSet( $interface->range );
+  foreach my $zone (values %{$self->elements->{zone}}) {
+    foreach my $interface (values %{$zone->interfaces}) {
+      $zone->range->mergeToSet($interface->range);
     }
   }
 }
 
 sub getInterface {
-  my ( $self, $name ) = @_;
-  return $self->getElement( 'interface', $name );
+  my ($self, $name) = @_;
+  return $self->getElement('interface', $name);
 }
 
 sub getZone {
-  my ( $self, $name ) = @_;
-  return $self->getElement( 'zone', $name );
+  my ($self, $name) = @_;
+  return $self->getElement('zone', $name);
 }
 
 sub getZoneFromIp {
-  my ( $self, $ip, $mask ) = @_;
-  my $addrSet = Firewall::Utils::Ip->new->getRangeFromIpMask( $ip, $mask );
-  for my $route (
-    sort { $b->mask <=> $a->mask }
-    grep { (
-      ( defined $_->{type} and ( $_->{type} eq 'static' or $_->{type} eq 'connected' ) ) or not defined $_->{type} ) }
-    values %{$self->elements->route}
-    )
+  my ($self, $ip, $mask) = @_;
+  my $addrSet = Firewall::Utils::Ip->new->getRangeFromIpMask($ip, $mask);
+  for my $route (sort { $b->mask <=> $a->mask }
+    grep { ((defined $_->{type} and ($_->{type} eq 'static' or $_->{type} eq 'connected')) or not defined $_->{type}) }
+    values %{$self->elements->route})
   {
 
-    if ( $route->range->isContain($addrSet) ) {
+    if ($route->range->isContain($addrSet)) {
       return $route->zoneName;
     }
   }
@@ -274,7 +271,7 @@ sub getZoneFromIp {
 } ## end sub getZoneFromIp
 
 sub parseInterfaceZone {
-  my ( $self, $string ) = @_;
+  my ($self, $string) = @_;
 
 =example
 set interface "ethernet0/0" zone "INS_DR"
@@ -289,7 +286,7 @@ set interface ethernet0/0 ip 172.20.255.81/29
     )
   {
     my $interface;
-    if ( not defined( $interface = $self->getInterface( $+{interfaceName} ) ) ) {
+    if (not defined($interface = $self->getInterface($+{interfaceName}))) {
       $interface = Firewall::Config::Element::Interface::Netscreen->new(
         fwId     => $self->fwId,
         name     => $+{interfaceName},
@@ -303,24 +300,19 @@ set interface ethernet0/0 ip 172.20.255.81/29
     }
 
     my $zone;
-    if ( not defined( $zone = $self->getZone( $+{zoneName} ) ) ) {
-      $zone = Firewall::Config::Element::Zone::Netscreen->new( fwId => $self->fwId, name => $+{zoneName},
-        config => $string );
+    if (not defined($zone = $self->getZone($+{zoneName}))) {
+      $zone = Firewall::Config::Element::Zone::Netscreen->new(fwId => $self->fwId, name => $+{zoneName}, config => $string);
       $self->addElement($zone);
     }
     $zone->addInterface($interface);
 
   }
-  elsif ( $string =~ /^set \s+ interface \s+ (?<interfaceName>\S+)\s+ ip \s+ (?<ipMask>\d+\.\d+\.\d+\.\d+\S+) \s*$/ox )
-  {
+  elsif ($string =~ /^set \s+ interface \s+ (?<interfaceName>\S+)\s+ ip \s+ (?<ipMask>\d+\.\d+\.\d+\.\d+\S+) \s*$/ox) {
     my $interface;
-    my ( $ipAddress, $mask ) = split( '/', $+{ipMask} );
-    if ( not defined( $interface = $self->getInterface( $+{interfaceName} ) ) ) {
-      $interface = Firewall::Config::Element::Interface::Netscreen->new(
-        fwId   => $self->fwId,
-        name   => $+{interfaceName},
-        config => $string
-      );
+    my ($ipAddress, $mask) = split('/', $+{ipMask});
+    if (not defined($interface = $self->getInterface($+{interfaceName}))) {
+      $interface
+        = Firewall::Config::Element::Interface::Netscreen->new(fwId => $self->fwId, name => $+{interfaceName}, config => $string);
       $self->addElement($interface);
     }
     else {
@@ -339,18 +331,15 @@ set interface ethernet0/0 ip 172.20.255.81/29
     $interface->addRoute($route);
     $self->addElement($route);
   }
-  elsif ( $string
+  elsif ($string
     =~ /^set \s+ interface \s+ (?<interfaceName>\S+)\s+ ip \s+ (?<ipMask>\d+\.\d+\.\d+\.\d+\s+\d+\.\d+\.\d+\.\d+)\s+ secondary\s*$/ox
     )
   {
     my $interface;
-    my ( $ipAddress, $mask ) = split( '\s+', $+{ipMask} );
-    if ( not defined( $interface = $self->getInterface( $+{interfaceName} ) ) ) {
-      $interface = Firewall::Config::Element::Interface::Netscreen->new(
-        fwId   => $self->fwId,
-        name   => $+{interfaceName},
-        config => $string
-      );
+    my ($ipAddress, $mask) = split('\s+', $+{ipMask});
+    if (not defined($interface = $self->getInterface($+{interfaceName}))) {
+      $interface
+        = Firewall::Config::Element::Interface::Netscreen->new(fwId => $self->fwId, name => $+{interfaceName}, config => $string);
       $self->addElement($interface);
     }
     else {
@@ -376,8 +365,8 @@ set interface ethernet0/0 ip 172.20.255.81/29
 #set route 10.0.0.0/8 interface ethernet0/0 gateway 10.37.172.200 preference 20
 #set route source 10.88.138.41/32 interface ethernet0/2.1 gateway 113.140.11.129
 sub isRoute {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /^set \s+ route \s+(source\s+)? \S+ \s+ (interface \s+ \S+ \s+)* /ox ) {
+  my ($self, $string) = @_;
+  if ($string =~ /^set \s+ route \s+(source\s+)? \S+ \s+ (interface \s+ \S+ \s+)* /ox) {
     $self->setElementType('route');
     return 1;
   }
@@ -388,12 +377,12 @@ sub isRoute {
 }
 
 sub getRoute {
-  my ( $self, $network, $mask ) = @_;
-  return $self->getElement( 'route', $network, $mask );
+  my ($self, $network, $mask) = @_;
+  return $self->getElement('route', $network, $mask);
 }
 
 sub parseRoute {
-  my ( $self, $string ) = @_;
+  my ($self, $string) = @_;
 
 =example
 set route 10.0.0.0/8 interface ethernet0/2 gateway 10.36.254.62
@@ -408,7 +397,7 @@ set route 172.20.24.0/22 gateway 172.20.255.86
         \s*/ox
     )
   {
-    my ( $network, $mask ) = split( '/', $+{networkMask} );
+    my ($network, $mask) = split('/', $+{networkMask});
     my $nextHop = $+{nextHop};
     my $intName = $+{name};
     return if $network !~ /\d+\.\d+\.\d+\.\d+/;    #maybe ipv6 not support now
@@ -419,7 +408,7 @@ set route 172.20.24.0/22 gateway 172.20.255.86
       nextHop => $nextHop,
       config  => $string
     );
-    if ( defined $intName ) {
+    if (defined $intName) {
       my $interface = $self->getInterface($intName);
       $route->{zoneName} = $interface->{zoneName};
     }
@@ -433,22 +422,20 @@ set route 172.20.24.0/22 gateway 172.20.255.86
     /ox
     )
   {
-    my ( $network, $mask ) = split( '/', $+{networkMask} );
+    my ($network, $mask) = split('/', $+{networkMask});
     my $route = Firewall::Config::Element::Route::Netscreen->new(
       fwId    => $self->fwId,
       network => $network,
       mask    => $mask,
       config  => $string
     );
-    my $interface = $self->getInterface( $+{name} );
+    my $interface = $self->getInterface($+{name});
 
     $interface->addRoute($route);
     $route->{zoneName} = $interface->{zoneName};
     $self->addElement($route);
   }
-  elsif (
-    $string =~ /set\s+route\s+source\s+(?<source>\S+)(\s+interface\s+(?<intName>\S+))?\s+gateway\s+(?<nextHop>\S+)/ )
-  {
+  elsif ($string =~ /set\s+route\s+source\s+(?<source>\S+)(\s+interface\s+(?<intName>\S+))?\s+gateway\s+(?<nextHop>\S+)/) {
     my %param;
     $param{type}      = 'policy';
     $param{srcIpmask} = $+{source};
@@ -458,7 +445,7 @@ set route 172.20.24.0/22 gateway 172.20.255.86
     $param{config}    = $string;
     my $route = Firewall::Config::Element::Route::Netscreen->new(%param);
     $self->addElement($route);
-    my $interface = $self->getInterface( $+{intName} );
+    my $interface = $self->getInterface($+{intName});
     $route->{zoneName} = $interface->{zoneName};
 
   }
@@ -468,8 +455,8 @@ set route 172.20.24.0/22 gateway 172.20.255.86
 } ## end sub parseRoute
 
 sub isStaticNat {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /set \s+ interface \s+ "[^"]+" \s+ mip \s+/ox ) {
+  my ($self, $string) = @_;
+  if ($string =~ /set \s+ interface \s+ "[^"]+" \s+ mip \s+/ox) {
     $self->setElementType('staticNat');
     return 1;
   }
@@ -480,7 +467,7 @@ sub isStaticNat {
 }
 
 sub parseStaticNat {
-  my ( $self, $string ) = @_;
+  my ($self, $string) = @_;
 
 =example
 set interface "ethernet0/0" mip 10.37.172.25 host 192.168.184.25 netmask 255.255.255.255 vr "trust-vr"
@@ -510,17 +497,17 @@ set interface "ethernet0/0" mip 10.37.172.25 host 192.168.184.25 netmask 255.255
     $param{config}       = $string;
     $param{fwId}         = $self->fwId;
     $param{natInterface} = $+{interface};
-    $param{natZone}      = $self->getInterface( $+{interface} )->{zoneName};
-    $param{mask}         = Firewall::Utils::Ip->new->changeMaskToNumForm( $+{mask} );
-    $param{realZone}     = $self->getZoneFromIp( $+{realIp}, $+{mask} );
+    $param{natZone}      = $self->getInterface($+{interface})->{zoneName};
+    $param{mask}         = Firewall::Utils::Ip->new->changeMaskToNumForm($+{mask});
+    $param{realZone}     = $self->getZoneFromIp($+{realIp}, $+{mask});
     $param{realIp}       = $+{realIp};
-    $param{realIpRange}  = Firewall::Utils::Ip->new->getRangeFromIpMask( $+{realIp}, $+{mask} );
+    $param{realIpRange}  = Firewall::Utils::Ip->new->getRangeFromIpMask($+{realIp}, $+{mask});
     $param{natIp}        = $+{natIp};
-    $param{natIpRange}   = Firewall::Utils::Ip->new->getRangeFromIpMask( $+{natIp}, $+{mask} );
+    $param{natIpRange}   = Firewall::Utils::Ip->new->getRangeFromIpMask($+{natIp}, $+{mask});
     my $staticNat = Firewall::Config::Element::StaticNat::Netscreen->new(%param);
     $self->addElement($staticNat);
 
-    if ( $param{mask} == 32 ) {
+    if ($param{mask} == 32) {
       my $address = Firewall::Config::Element::Address::Netscreen->new(
         fwId        => $self->fwId,
         addrName    => "MIP($+{natIp})",
@@ -532,7 +519,7 @@ set interface "ethernet0/0" mip 10.37.172.25 host 192.168.184.25 netmask 255.255
       $self->addElement($address);
     }
     else {
-      my $maskNum = Firewall::Utils::Ip->new->changeMaskToNumForm( $param{mask} );
+      my $maskNum = Firewall::Utils::Ip->new->changeMaskToNumForm($param{mask});
       my $address = Firewall::Config::Element::Address::Netscreen->new(
         fwId        => $self->fwId,
         addrName    => "MIP($+{natIp}/$maskNum)",
@@ -550,8 +537,8 @@ set interface "ethernet0/0" mip 10.37.172.25 host 192.168.184.25 netmask 255.255
 } ## end sub parseStaticNat
 
 sub isAddress {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /^set \s+ address \s+/ox ) {
+  my ($self, $string) = @_;
+  if ($string =~ /^set \s+ address \s+/ox) {
     $self->setElementType('address');
     return 1;
   }
@@ -562,13 +549,13 @@ sub isAddress {
 }
 
 sub getAddress {
-  my ( $self, $zone, $addrName ) = @_;
+  my ($self, $zone, $addrName) = @_;
   $zone = 'Global' if $addrName =~ /^MIP\(.+\)$/;
-  return $self->getElement( 'address', $zone, $addrName );
+  return $self->getElement('address', $zone, $addrName);
 }
 
 sub parseAddress {
-  my ( $self, $string ) = @_;
+  my ($self, $string) = @_;
 
 =example
 set address "V1-Untrust" "Host_10.29.38.10" 10.29.38.10 255.255.255.255 "hsh-1219"
@@ -605,8 +592,8 @@ set address "V1-Untrust" "Host_10.29.38.10" 10.29.38.10 255.255.255.255 "hsh-121
 } ## end sub parseAddress
 
 sub isAddressGroup {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /^set \s+ group \s+ address \s+/ox ) {
+  my ($self, $string) = @_;
+  if ($string =~ /^set \s+ group \s+ address \s+/ox) {
     $self->setElementType('addressGroup');
     return 1;
   }
@@ -617,12 +604,12 @@ sub isAddressGroup {
 }
 
 sub getAddressGroup {
-  my ( $self, $zone, $addrGroupName ) = @_;
-  return $self->getElement( 'addressGroup', $zone, $addrGroupName );
+  my ($self, $zone, $addrGroupName) = @_;
+  return $self->getElement('addressGroup', $zone, $addrGroupName);
 }
 
 sub parseAddressGroup {
-  my ( $self, $string ) = @_;
+  my ($self, $string) = @_;
 
 =example
 set group address "V1-Trust" "g_cache_server" comment " "
@@ -663,14 +650,13 @@ set group address "V1-Trust" "A_LINUX_DNS_2012" add "H_10.31.120.2"
     )
   {
     my $addressGroup;
-    if ( $addressGroup = $self->getAddressGroup( $+{zone}, $+{addrGroupName} ) ) {
+    if ($addressGroup = $self->getAddressGroup($+{zone}, $+{addrGroupName})) {
       $addressGroup->{config} .= "\n" . $string;
-      my $obj = $self->getAddressOrAddressGroupFromAddrGroupMemberName( $+{zone}, $+{addrGroupMemberName} );
-      if ( not defined $obj ) {
-        $self->warn(
-          "addrGroup $+{addrGroupName} 的 addrGroupMember $+{addrGroupMemberName} 既不是 address 也不是 addressGroup\n");
+      my $obj = $self->getAddressOrAddressGroupFromAddrGroupMemberName($+{zone}, $+{addrGroupMemberName});
+      if (not defined $obj) {
+        $self->warn("addrGroup $+{addrGroupName} 的 addrGroupMember $+{addrGroupMemberName} 既不是 address 也不是 addressGroup\n");
       }
-      $addressGroup->addAddrGroupMember( $+{addrGroupMemberName}, $obj );
+      $addressGroup->addAddrGroupMember($+{addrGroupMemberName}, $obj);
 
     }
     else {
@@ -683,15 +669,15 @@ set group address "V1-Trust" "A_LINUX_DNS_2012" add "H_10.31.120.2"
 } ## end sub parseAddressGroup
 
 sub getAddressOrAddressGroupFromAddrGroupMemberName {
-  my ( $self, $zone, $addrGroupMemberName ) = @_;
-  my $obj = $self->getAddress( $zone, $addrGroupMemberName ) // $self->getAddressGroup( $zone, $addrGroupMemberName )
-    // $self->getAddress( 'Global', $addrGroupMemberName ) // $self->getAddressGroup( 'Global', $addrGroupMemberName );
+  my ($self, $zone, $addrGroupMemberName) = @_;
+  my $obj = $self->getAddress($zone, $addrGroupMemberName) // $self->getAddressGroup($zone, $addrGroupMemberName)
+    // $self->getAddress('Global', $addrGroupMemberName) // $self->getAddressGroup('Global', $addrGroupMemberName);
   return $obj;
 }
 
 sub isService {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /^set \s+ service \s+/ox ) {
+  my ($self, $string) = @_;
+  if ($string =~ /^set \s+ service \s+/ox) {
     $self->setElementType('service');
     return 1;
   }
@@ -702,18 +688,18 @@ sub isService {
 }
 
 sub getService {
-  my ( $self, $srvName ) = @_;
-  return $self->getElement( 'service', $srvName );
+  my ($self, $srvName) = @_;
+  return $self->getElement('service', $srvName);
 }
 
 sub getPreDefinedService {
-  my ( $self, $srvName ) = @_;
+  my ($self, $srvName) = @_;
   my $sign = Firewall::Config::Element::Service::Netscreen->createSign($srvName);
-  return ( $self->preDefinedService->{$sign} );
+  return ($self->preDefinedService->{$sign});
 }
 
 sub parseService {
-  my ( $self, $string ) = @_;
+  my ($self, $string) = @_;
 
 =example
 set service "TCP/UDP_42430" protocol tcp src-port 0-65535 dst-port 42430-42430
@@ -776,7 +762,7 @@ set service "my-sunrpc-nfs" + sun-rpc program 100227-100227
     )
   {
     my $service;
-    if ( $service = $self->getService( $+{srvName} ) ) {
+    if ($service = $self->getService($+{srvName})) {
       $service->{config} .= "\n" . $string;
       $service->addMeta(
         fwId     => $self->fwId,
@@ -791,14 +777,14 @@ set service "my-sunrpc-nfs" + sun-rpc program 100227-100227
       $self->warn("$string 缺少预定义行\n");
     }
   }
-  elsif ( $string =~ /^set \s+ service \s+ "(?<srvName>[^"]+)" \s+ timeout \s+ (?<timeout>\w+) \s*$/ox ) {
+  elsif ($string =~ /^set \s+ service \s+ "(?<srvName>[^"]+)" \s+ timeout \s+ (?<timeout>\w+) \s*$/ox) {
     my $service;
-    if ( $service = $self->getService( $+{srvName} ) ) {
-      $service->setTimeout( $+{timeout} );
+    if ($service = $self->getService($+{srvName})) {
+      $service->setTimeout($+{timeout});
       $service->{config} .= "\n" . $string;
     }
-    elsif ( $self->getPreDefinedService( $+{srvName} ) ) {
-      if ( my $service = $self->getService( $+{srvName} ) ) {
+    elsif ($self->getPreDefinedService($+{srvName})) {
+      if (my $service = $self->getService($+{srvName})) {
         $service->{config} .= "\n" . $string;
       }
     }
@@ -806,7 +792,7 @@ set service "my-sunrpc-nfs" + sun-rpc program 100227-100227
       $self->warn("$string 缺少预定义行\n");
     }
   }
-  elsif ( $string =~ /^set \s+ service \s+ "[^"]+" \s+ (?:protocol|\+) \s+ \S+ \s+ program \s+ \d+-\d+ \s*$/ox ) {
+  elsif ($string =~ /^set \s+ service \s+ "[^"]+" \s+ (?:protocol|\+) \s+ \S+ \s+ program \s+ \d+-\d+ \s*$/ox) {
 
     #忽略这种情况
   }
@@ -816,8 +802,8 @@ set service "my-sunrpc-nfs" + sun-rpc program 100227-100227
 } ## end sub parseService
 
 sub isServiceGroup {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /^set \s+ group \s+ service \s+/ox ) {
+  my ($self, $string) = @_;
+  if ($string =~ /^set \s+ group \s+ service \s+/ox) {
     $self->setElementType('serviceGroup');
     return 1;
   }
@@ -828,12 +814,12 @@ sub isServiceGroup {
 }
 
 sub getServiceGroup {
-  my ( $self, $srvGroupName ) = @_;
-  return $self->getElement( 'serviceGroup', $srvGroupName );
+  my ($self, $srvGroupName) = @_;
+  return $self->getElement('serviceGroup', $srvGroupName);
 }
 
 sub parseServiceGroup {
-  my ( $self, $string ) = @_;
+  my ($self, $string) = @_;
 
 =example
 set group service "BKUP_SERVICES" comment " "
@@ -874,15 +860,15 @@ set group service "BKUP_SERVICES" add "TCP/UDP_27238"
     )
   {
     my $serviceGroup;
-    if ( $serviceGroup = $self->getServiceGroup( $+{srvGroupName} ) ) {
+    if ($serviceGroup = $self->getServiceGroup($+{srvGroupName})) {
       $serviceGroup->{config} .= "\n" . $string;
-      my $obj = $self->getServiceOrServiceGroupFromSrvGroupMemberName( $+{srvGroupMemberName} );
-      if ( not defined $obj ) {
+      my $obj = $self->getServiceOrServiceGroupFromSrvGroupMemberName($+{srvGroupMemberName});
+      if (not defined $obj) {
         $self->warn(
           "srvGroup $+{srvGroupName} 的 srvGroupMember $+{srvGroupMemberName} 既不是 service 不是 pre-defined service 也不是 service Group\n"
         );
       }
-      $serviceGroup->addSrvGroupMember( $+{srvGroupMemberName}, $obj );
+      $serviceGroup->addSrvGroupMember($+{srvGroupMemberName}, $obj);
 
     }
     else {
@@ -895,15 +881,15 @@ set group service "BKUP_SERVICES" add "TCP/UDP_27238"
 } ## end sub parseServiceGroup
 
 sub getServiceOrServiceGroupFromSrvGroupMemberName {
-  my ( $self, $srvGroupMemberName ) = @_;
+  my ($self, $srvGroupMemberName) = @_;
   my $obj = $self->getPreDefinedService($srvGroupMemberName) // $self->getService($srvGroupMemberName)
     // $self->getServiceGroup($srvGroupMemberName);
   return $obj;
 }
 
 sub isSchedule {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /^set \s+ scheduler \s+/ox ) {
+  my ($self, $string) = @_;
+  if ($string =~ /^set \s+ scheduler \s+/ox) {
     $self->setElementType('schedule');
     return 1;
   }
@@ -914,12 +900,12 @@ sub isSchedule {
 }
 
 sub getSchedule {
-  my ( $self, $schName ) = @_;
-  return $self->getElement( 'schedule', $schName );
+  my ($self, $schName) = @_;
+  return $self->getElement('schedule', $schName);
 }
 
 sub parseSchedule {
-  my ( $self, $string ) = @_;
+  my ($self, $string) = @_;
 
 =example
 set scheduler "S_20120331" once start 10/10/2011 0:0 stop 3/31/2012 23:59
@@ -1000,13 +986,13 @@ set scheduler "S20110630" recurrent friday start 10:00 stop 12:00 start 14:00 st
 } ## end sub parseSchedule
 
 sub getDynamicNat {
-  my ( $self, $policyId ) = @_;
-  return $self->getElement( 'dynamicNat', $policyId );
+  my ($self, $policyId) = @_;
+  return $self->getElement('dynamicNat', $policyId);
 }
 
 sub isRule {
-  my ( $self, $string ) = @_;
-  if ( $string =~ /^set \s+ policy \s+ id \s+ \d+ \s+ (from|name)/ox ) {
+  my ($self, $string) = @_;
+  if ($string =~ /^set \s+ policy \s+ id \s+ \d+ \s+ (from|name)/ox) {
     $self->setElementType('rule');
     return 1;
   }
@@ -1017,12 +1003,12 @@ sub isRule {
 }
 
 sub getRule {
-  my ( $self, $policyId ) = @_;
-  return $self->getElement( 'rule', $policyId );
+  my ($self, $policyId) = @_;
+  return $self->getElement('rule', $policyId);
 }
 
 sub parseRule {
-  my ( $self, $string ) = @_;
+  my ($self, $string) = @_;
 
 =example
 set policy id 697 from "Trust" to "Global"  "Host_10.8.35.88" "MIP(10.37.174.134)" "S_BIB-TPDS_never" permit log sess-limit per-src-ip 3200
@@ -1081,11 +1067,11 @@ exit
     {
 
       $policyId = $+{policyId};
-      if ( $self->getRule($policyId) ) {
+      if ($self->getRule($policyId)) {
         $self->warn("id 为 $policyId 的 rule 的声明出现了两次\n");
         return;
       }
-      my ( $alias, $fromZone, $toZone, $srcAddrName, $dstAddrName, $srvName, $other )
+      my ($alias, $fromZone, $toZone, $srcAddrName, $dstAddrName, $srvName, $other)
         = @{+}{qw/ alias fromZone toZone srcAddrName dstAddrName srvName other /};
       if (
         $other =~ /^
@@ -1119,27 +1105,27 @@ exit
           content  => $string,
           priority => $self->lineNumber
         );
-        if ( defined $+{schName} ) {
-          if ( my $schedule = $self->getSchedule( $+{schName} ) ) {
+        if (defined $+{schName}) {
+          if (my $schedule = $self->getSchedule($+{schName})) {
             $rule->setSchedule($schedule);
           }
           else {
             $self->warn("schName $+{schName} 不是 schedule\n");
           }
         }
-        if ( defined $+{poolName} or defined $+{dstIp} ) {
-          my $natDirection = ( defined $+{poolName} ? 'source' : '' ) . ( defined $+{dstIp} ? 'destination' : '' );
+        if (defined $+{poolName} or defined $+{dstIp}) {
+          my $natDirection = (defined $+{poolName} ? 'source' : '') . (defined $+{dstIp} ? 'destination' : '');
           my $natSrcPool;
           my $natSrcIpRange;
           my $natDstIpRange;
 
           #my $dstIpRange;
-          if ( defined $+{dstIp} ) {
-            $natDstIpRange = Firewall::Utils::Ip->new->getRangeFromIpMask( $+{dstIp} );
+          if (defined $+{dstIp}) {
+            $natDstIpRange = Firewall::Utils::Ip->new->getRangeFromIpMask($+{dstIp});
           }
-          if ( defined $+{poolName} ) {
-            $natSrcPool = $self->getNatPool( $+{poolName} );
-            if ( not defined $natSrcPool ) {
+          if (defined $+{poolName}) {
+            $natSrcPool = $self->getNatPool($+{poolName});
+            if (not defined $natSrcPool) {
               confess("防火墙ID $self->fwId 的pool dip $+{poolName}未分析完整");
             }
             $natSrcIpRange = $natSrcPool->poolRange;
@@ -1155,7 +1141,7 @@ exit
           $natParam{config}        = $string;
           $natParam{dstIpRange}    = $natDstIpRange if defined $natDstIpRange;    #目的nat，nat之后的为真实地址
 
-          if ( defined $+{natPort} ) {
+          if (defined $+{natPort}) {
 
             #realPort
             $natParam{srvRange} = Firewall::Utils::Ip->new->getRangeFromService("tcp/$+{natPort}");
@@ -1168,9 +1154,9 @@ exit
         $self->addElement($rule);
         my $index = $fromZone . $toZone;
         push @{$self->{ruleIndex}{$index}}, $rule;
-        $self->addToRuleSrcAddressGroup( $rule, $srcAddrName );
-        $self->addToRuleDstAddressGroup( $rule, $dstAddrName );
-        $self->addToRuleServiceGroup( $rule, $srvName );
+        $self->addToRuleSrcAddressGroup($rule, $srcAddrName);
+        $self->addToRuleDstAddressGroup($rule, $dstAddrName);
+        $self->addToRuleServiceGroup($rule, $srvName);
       }
       else {
         $policyId = undef;
@@ -1178,49 +1164,48 @@ exit
       }
 
     }
-    elsif ( not defined $policyId ) {
+    elsif (not defined $policyId) {
       $self->warn("本行 [$string] 所在的rule的声明行分析失败\n");
     }
     else {
       my $rule = $self->getRule($policyId);
       $rule->addContent($string);
       my $dynamicNat = $self->getDynamicNat($policyId);
-      if ( defined $dynamicNat ) {
+      if (defined $dynamicNat) {
         $dynamicNat->{config} .= "\n" . $string;
       }
-      if ( $string =~ /^set \s+ policy \s+ id \s+ $policyId \s+ (?<isDisable>disable) \s*$/x ) {
-        $rule->setIsDisable( $+{isDisable} );
+      if ($string =~ /^set \s+ policy \s+ id \s+ $policyId \s+ (?<isDisable>disable) \s*$/x) {
+        $rule->setIsDisable($+{isDisable});
       }
-      elsif ( $string =~ /^set \s+ policy \s+ id \s+ $policyId \s+ application \s+ "(?<applicationCheck>[^"]+)" \s*$/x )
-      {
-        $rule->setHasApplicationCheck( $+{applicationCheck} );
+      elsif ($string =~ /^set \s+ policy \s+ id \s+ $policyId \s+ application \s+ "(?<applicationCheck>[^"]+)" \s*$/x) {
+        $rule->setHasApplicationCheck($+{applicationCheck});
       }
-      elsif ( $string =~ /^set \s+ policy \s+ id \s+ $policyId \s*$/x ) {
+      elsif ($string =~ /^set \s+ policy \s+ id \s+ $policyId \s*$/x) {
       }
-      elsif ( $string =~ /^set \s+ src-address \s+ "(?<srcAddrName>[^"]+)" \s*$/ox ) {
-        $self->addToRuleSrcAddressGroup( $rule, $+{srcAddrName} );
+      elsif ($string =~ /^set \s+ src-address \s+ "(?<srcAddrName>[^"]+)" \s*$/ox) {
+        $self->addToRuleSrcAddressGroup($rule, $+{srcAddrName});
       }
-      elsif ( $string =~ /^set \s+ dst-address \s+ "(?<dstAddrName>[^"]+)" \s*$/ox ) {
-        $self->addToRuleDstAddressGroup( $rule, $+{dstAddrName} );
+      elsif ($string =~ /^set \s+ dst-address \s+ "(?<dstAddrName>[^"]+)" \s*$/ox) {
+        $self->addToRuleDstAddressGroup($rule, $+{dstAddrName});
       }
-      elsif ( $string =~ /^set \s+ service \s+ "(?<srvName>[^"]+)" \s*$/ox ) {
-        $self->addToRuleServiceGroup( $rule, $+{srvName} );
+      elsif ($string =~ /^set \s+ service \s+ "(?<srvName>[^"]+)" \s*$/ox) {
+        $self->addToRuleServiceGroup($rule, $+{srvName});
       }
-      elsif ( $string =~ /^set \s+ log \s+ session-init \s*$/ox ) {
+      elsif ($string =~ /^set \s+ log \s+ session-init \s*$/ox) {
 
         #暂时忽略
       }
-      elsif ( $string =~ /^exit\s*$/o ) {
+      elsif ($string =~ /^exit\s*$/o) {
         my $dynamicNat = $self->getDynamicNat($policyId);
-        if ( defined $dynamicNat ) {
+        if (defined $dynamicNat) {
           $dynamicNat->{srcIpRange} = $rule->srcAddressGroup->range;
-          if ( $dynamicNat->natDirection eq 'destination' ) {
+          if ($dynamicNat->natDirection eq 'destination') {
             $dynamicNat->{natDstIpRange} = $rule->dstAddressGroup->range;
           }
           else {
             $dynamicNat->{dstIpRange} = $rule->dstAddressGroup->range;
           }
-          if ( defined $dynamicNat->{srvRange} ) {
+          if (defined $dynamicNat->{srvRange}) {
             $dynamicNat->{natSrvRange} = $rule->serviceGroup->range;
           }
           else {
@@ -1233,15 +1218,15 @@ exit
         $self->warn("id 为 $policyId 的行 [$string] 分析不出来\n");
       }
     } ## end else [ if ( $string =~ /^set \s+ policy \s+ id )]
-  } while ( $string = $self->nextUnParsedLine );
+  } while ($string = $self->nextUnParsedLine);
 } ## end sub parseRule
 
 sub addToRuleSrcAddressGroup {
-  my ( $self, $rule, $srcAddrName ) = @_;
+  my ($self, $rule, $srcAddrName) = @_;
 
   my $obj;
-  if ( $srcAddrName =~ /^Any$|any-ipv4/io ) {
-    unless ( $obj = $self->getAddress( $rule->fromZone, $srcAddrName ) ) {
+  if ($srcAddrName =~ /^Any$|any-ipv4/io) {
+    unless ($obj = $self->getAddress($rule->fromZone, $srcAddrName)) {
       $obj = Firewall::Config::Element::Address::Netscreen->new(
         fwId     => $self->fwId,
         addrName => $srcAddrName,
@@ -1252,22 +1237,22 @@ sub addToRuleSrcAddressGroup {
       $self->addElement($obj);
     }
   }
-  elsif ( $obj = $self->getAddressOrAddressGroupFromAddrGroupMemberName( $rule->fromZone, $srcAddrName ) ) {
+  elsif ($obj = $self->getAddressOrAddressGroupFromAddrGroupMemberName($rule->fromZone, $srcAddrName)) {
     $obj->{refnum} += 1;
   }
   else {
     $self->warn("的 srcAddrName $srcAddrName 不是address 也不是 addressGroup\n");
   }
 
-  $rule->addSrcAddressMembers( $srcAddrName, $obj );
+  $rule->addSrcAddressMembers($srcAddrName, $obj);
 } ## end sub addToRuleSrcAddressGroup
 
 sub addToRuleDstAddressGroup {
-  my ( $self, $rule, $dstAddrName ) = @_;
+  my ($self, $rule, $dstAddrName) = @_;
 
   my $obj;
-  if ( $dstAddrName =~ /^Any$|Any-IPv4/io ) {
-    unless ( $obj = $self->getAddress( $rule->toZone, $dstAddrName ) ) {
+  if ($dstAddrName =~ /^Any$|Any-IPv4/io) {
+    unless ($obj = $self->getAddress($rule->toZone, $dstAddrName)) {
       $obj = Firewall::Config::Element::Address::Netscreen->new(
         fwId     => $self->fwId,
         addrName => $dstAddrName,
@@ -1278,28 +1263,28 @@ sub addToRuleDstAddressGroup {
       $self->addElement($obj);
     }
   }
-  elsif ( $obj = $self->getAddressOrAddressGroupFromAddrGroupMemberName( $rule->toZone, $dstAddrName ) ) {
+  elsif ($obj = $self->getAddressOrAddressGroupFromAddrGroupMemberName($rule->toZone, $dstAddrName)) {
     $obj->{refnum} += 1;
   }
   else {
     $self->warn("的 dstAddrName $dstAddrName 不是address 也不是 addressGroup\n");
   }
 
-  $rule->addDstAddressMembers( $dstAddrName, $obj );
+  $rule->addDstAddressMembers($dstAddrName, $obj);
 } ## end sub addToRuleDstAddressGroup
 
 sub addToRuleServiceGroup {
-  my ( $self, $rule, $srvName ) = @_;
+  my ($self, $rule, $srvName) = @_;
 
   my $obj;
-  if ( $obj = $self->getServiceOrServiceGroupFromSrvGroupMemberName($srvName) ) {
+  if ($obj = $self->getServiceOrServiceGroupFromSrvGroupMemberName($srvName)) {
     $obj->{refnum} += 1;
   }
   else {
     $self->warn("的 srvName $srvName 不是 service 不是 preDefinedService 也不是 serviceGroup\n");
   }
 
-  $rule->addServiceMembers( $srvName, $obj );
+  $rule->addServiceMembers($srvName, $obj);
 }
 
 __PACKAGE__->meta->make_immutable;
